no_op = [
    {
        "type": "card",
        "theme": "secondary",
        "size": "lg",
        "color": "#00ff00",
        "modules": [
            {
                "type": "section",
                "text": {
                    "type": "kmarkdown",
                    "content": "查找完成，当前没有(font)原批(font)[purple]！"
                }
            }
        ]
    }
]


def op_unit(avatar, name, time):
    return {
        "type": "section",
        "text": {
            "type": "kmarkdown",
            "content": f"(font){name}(font)[danger] 当前时长: (font){time}(font)[danger] 分钟"
        },
        "mode": "left",
        "accessory": {
            "type": "image",
            "src": avatar,
            "size": "lg"
        }
    }


def op_template(users):
    return [
        {
            "type": "card",
            "theme": "secondary",
            "size": "lg",
            "color": "#ff0000",
            "modules": [
                {
                    "type": "section",
                    "text": {
                        "type": "kmarkdown",
                        "content": "查找完成，发现(font)原批(font)[purple]！"
                    }
                },
                {
                    "type": "divider"
                }
            ] + [op_unit(i[0], i[1], i[2]) for i in users]
        }
    ]


def init():
    from nonebot import on_command
    from nonebot.adapters.kaiheila import Bot as KookBot
    from nonebot.adapters.kaiheila import Event as KookEvent
    from nonebot.adapters.kaiheila import MessageSegment

    from nonebot import logger
    from .lib import get_ops
    import time

    op_finder = on_command("查找原批", aliases={"op", "原批"})

    @op_finder.handle()
    async def _(bot: KookBot, event: KookEvent):
        # logger.debug(f"channel_type: {event.channel_type}")
        if event.channel_type == "PERSON":
            op_finder.finish()
        channel_id = event.target_id
        guild_id = event.extra.guild_id
        logger.debug(f"收到来自 guild_id|channel_id:{guild_id}|{channel_id} 的消息")
        op_users = await get_ops(guild_id)

        if len(op_users) == 0:
            # await bot.call_api("game/activity", id=1500242, data_type=1)
            await op_finder.finish(MessageSegment.Card(no_op))
        else:
            # await bot.call_api("game/delete-activity", data_type=1)
            await op_finder.finish(MessageSegment.Card(op_template(op_users)))



__version__ = "1.0.0"

from nonebot import get_driver
from nonebot.plugin import PluginMetadata

from .config import Config
from .lib import init as lib_init
from .app import init as app_init

__plugin_meta = PluginMetadata(
    name="op-finder",
    description="显示当前正在玩原神的人",
    usage="/查找原批 /op /原批",
    type="application",
    homepage='https://github.com/ninthseason/nonebot-plugin-op-finder',
    supported_adapters={"~kaiheila"},
    config=Config,
)

global_config = get_driver().config
config = Config.parse_obj(global_config)

if config.kook_auth_key is None:
    raise ValueError("配置项kook_auth_key未设置")

lib_init(config)
app_init()



import asyncio
import time
import aiohttp
from .config import Config

cookies = {
    'auth': '',
}

headers = {
    'authority': 'www.kookapp.cn',
    'accept': '*/*',
    'accept-language': 'zh',
    'content-type': 'application/json; charset=utf-8',
    'referer': 'https://www.kookapp.cn/app/channels/2127841922601861/3735309828842826',
    'sec-ch-ua': '"Google Chrome";v="117", "Not;A=Brand";v="8", "Chromium";v="117"',
    'sec-ch-ua-mobile': '?0',
    'sec-ch-ua-platform': '"Windows"',
    'sec-fetch-dest': 'empty',
    'sec-fetch-mode': 'cors',
    'sec-fetch-site': 'same-origin',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/117.0.0.0 Safari/537.36',
    'x-client-sessionid': 'c13d75c7-ed00-45cf-947e-deedf0bf11e6',
    'x-client-utm': 'official.site....pc',
}


def init(config: Config):
    cookies['auth'] = config.kook_auth_key


async def get_user_game_and_music(user_id):
    async with aiohttp.ClientSession() as session:
        response = await session.request("GET", f'https://www.kookapp.cn/api/v2/users/{user_id}', cookies=cookies,
                                         headers=headers)
        result = await response.json()
        return [result.get("game", None), result.get("music", None)]


async def get_ops(guild_id):
    op_list = []
    left_count = 600
    offset = 0
    while left_count > 500:
        params = {
            'offset': f'{offset}',
            'perPage': '500',
        }
        async with aiohttp.ClientSession() as session:
            response = await session.get(
                f'https://www.kookapp.cn/api/v2/guilds/users-v2/{guild_id}',
                params=params,
                cookies=cookies,
                headers=headers,
            )
            result = await response.json()
            left_count = result['count']
            offset += 500
            for i in result['data']:
                if i['online'] and i.get("game", False) and i['game']['name'] == "原神":
                    op_list.append([i['vip_avatar'], i['nickname'], (time.time() - int(i['game']['start_time'])) // 60])
    return op_list

if __name__ == '__main__':
    async def main():
        print(await get_user_game_and_music(239017136))


    asyncio.run(main())
